@@ -138,10 +138,13 @@ class Release:
             self._deploy(new_version)
 
     def _deploy(self, version=""):
-        countries = prompt_utils.ask_multiple_choices(
-            "Which countries do you want to deploy to?",
-            self._countries,
-        )
+        if len(self._countries) > 1:
+            countries = prompt_utils.ask_multiple_choices(
+                "Which countries do you want to deploy to?",
+                self._countries,
+            )
+        else:
+            countries = self._countries
 
         if not version:
             current = self._get_current_versions(countries)
