@@ -137,19 +137,22 @@ class DroneHandler:
                     f"{BASEURL}/api/repos/primait/{self._repo}/builds?per_page=100",
                     headers={"Authorization": f"Bearer {self._token}"},
                 ).json()
-                builds = [
-                    {
-                        "country": country,
-                        "version": max(
-                            b["params"]["DRONE_TAG"]
-                            for b in builds
-                            if b["event"] == "promote"
-                            and b["deploy_to"] == f"deploy-{country}-production"
-                        ),
-                    }
-                    for country in countries
-                ]
-                return builds
+                try:
+                    return [
+                        {
+                            "country": country,
+                            "version": max(
+                                b["params"]["DRONE_TAG"]
+                                for b in builds
+                                if b["event"] == "promote"
+                                and b["deploy_to"] == f"deploy-{country}-production"
+                            ),
+                        }
+                        for country in countries
+                    ]
+                except Exception:
+                    return []
+
             except Exception as e:
                 logger.error(f"Unable to retrieve last deploy: {e}")
                 sys.exit(-1)
