@@ -1,4 +1,5 @@
 # -*- encoding: utf-8 -*-
+from itertools import groupby
 import os
 import re
 import subprocess
@@ -301,3 +302,24 @@ def is_semver(tag):
         return semver.parse(tag)
     except Exception:
         return None
+
+
+def get_commit_logs(base_branch):
+    """
+    Get all the commits from HEAD that are *not* in `base_branch` and return
+    their logs as a list. The commits are orderded from latest to first.
+    """
+    commits = subprocess.check_output(
+        ["git", "log", "--pretty=medium", f"HEAD...{base_branch}"]
+    ).decode("utf-8")
+
+    commits_list = [
+        "\n".join([line.lstrip() for line in split_result])
+        for is_commit_line, split_result in groupby(
+            commits.split("\n"),
+            lambda line: re.match("commit [0-9a-f]{40}", line) is not None,
+        )
+        if not is_commit_line
+    ]
+
+    return commits_list
