@@ -2,7 +2,7 @@
 import re
 
 from youtrack.connection import Connection
-from youtrack.youtrack import YouTrackException
+from youtrack import YouTrackException
 
 
 REGEX = r"([A-Za-z]+-[0-9]+)"
